@@ -6,11 +6,11 @@ fn test_spot() {
     match blocking::spot(52.520008, 13.404954, 0.0) {
         Ok(spots) => {
             // count upcoming spots
-            let upcoming = find_upcoming(&spots,None);
+            let upcoming = find_upcoming(&spots,&None);
             assert!(upcoming.is_some());
             let upcoming = upcoming.unwrap();
             println!("{}", upcoming.risetime );
-            match find_current(&spots,None) {
+            match find_current(&spots,&None) {
                 Some(current) => {
                     println!("{}", current.risetime );
                     assert!(upcoming.risetime != current.risetime);
